==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_grand' => 'Великий екран',
	'affichage_documents_en_liste_compacte' => 'Компактні списки',
	'aucun_audio' => 'Нема аудіо файлів ',
	'aucun_document' => 'Нема документів (файлів)',
	'aucun_file' => 'Нема документів (файлів)',
	'aucun_image' => 'Нема файлів зображень',
	'aucun_video' => 'Нема відео файлів',
	'aucune_utilisation' => 'Документ не використовується.',
	'aucune_vignette' => 'Нема мініатюр',

	// B
	'bouton_ajouter_document' => 'Додати документ',
	'bouton_ajouter_image' => 'Додати зображення',
	'bouton_ajouter_image_document' => 'Додати зображення або документ',
	'bouton_attacher_document' => 'Додати',
	'bouton_copier_local' => 'Додати на сайт',
	'bouton_download_depuis' => 'додати файли:',
	'bouton_download_local' => 'з мого комп’ютера',
	'bouton_download_par_ftp' => 'з сервера',
	'bouton_download_par_mediatheque' => 'із доданих',
	'bouton_download_sur_le_web' => 'з інтернету',
	'bouton_enlever_document' => 'Відкріпити',
	'bouton_enlever_supprimer_document' => 'Видалити',
	'bouton_enlever_supprimer_document_confirmation' => 'Ви певні, що хочете видалити документ (файл)?',
	'bouton_modifier_document' => 'Змінити',
	'bouton_parcourir' => 'Огляд...',
	'bouton_refresh_document' => 'Поновити документ',
	'bouton_remplacer_document' => 'Замінити документ',
	'bouton_remplacer_image' => 'Замінити зображення',
	'bouton_remplacer_image_document' => 'Замінити зображенням або файлом',
	'bouton_supprimer' => 'Видалити',
	'bouton_supprimer_tous_orphelins' => 'Видалити ті, що не використовуються',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Ви дійсно хочете видалити @nb@ документів (файлів)?',
	'bouton_upload' => 'Додати',

	// D
	'des_audios' => '@nb@ аудіо файлів',
	'des_documents' => '@nb@ документів (файлів)',
	'des_files' => '@nb@ документів (файлів)',
	'des_images' => '@nb@ файлів зображень',
	'des_utilisations' => 'Використовується @nb@ раз(ів)',
	'des_videos' => '@nb@ відео файлів',
	'descriptif' => 'Опис',
	'details_document' => 'Деталі',
	'details_document_afficher_masquer' => 'Показати / сховати деталі документу',
	'document_attache_succes' => 'Документ (файл) доданий успішно',
	'document_copie_locale_succes' => 'Файл успішно скопійований на сайт',
	'document_installe_succes' => 'Файл доданий успішно',
	'document_vu' => 'В тексті',
	'documents' => 'Управління файлами',
	'documents_brises' => 'Пошкоджені',
	'documents_distants' => 'На інших сайтах',
	'documents_locaux' => 'На нашому сайті',
	'documents_non_publies' => 'Не опубліковані',
	'documents_orphelins' => 'Не використовуються',
	'documents_publies' => 'На сайті',
	'documents_tous' => 'Усі',
	'double_clic_inserer_doc' => 'Двічі клацніть, щоб вставити цей ярлик в текст',

	// E
	'entree_dimensions' => 'Розмір:',
	'entree_titre_document' => 'Назва документа:',
	'entree_titre_image' => 'Назва зображення:',
	'erreur_aucun_document' => 'Цього документу нема в модулі управління файлами',
	'erreur_aucun_fichier' => 'Файл не знайдений',
	'erreur_autorisation' => 'Проблема авторизації.',
	'erreur_chemin_distant' => 'Файл @nom@ з іншого сайту не знайдений',
	'erreur_chemin_ftp' => 'Не вдалося знайти вказаний файл на сервері',
	'erreur_copie_fichier' => 'Неможливо скопіювати файл @nom@ до вказаної папки',
	'erreur_deplacement_impossible' => 'Неможливо перемістити.',
	'erreur_dossier_tmp_manquant' => 'Не вдається створити тимчасову папку для завантаження файлів',
	'erreur_ecriture_fichier' => 'Помилка при спробі записати на диск',
	'erreur_format_fichier_image' => 'Формат файлу @nom@ не схожий на формат зображення',
	'erreur_indiquez_un_fichier' => 'Вкажіть файл!',
	'erreur_insertion_document_base' => 'Не вдається додати документ @fichier@ до бази даних',
	'erreur_objet_absent' => 'Інформації недостатньо.',
	'erreur_suppression_vignette' => 'При видаленні мініатюри виникла помилка',
	'erreur_upload_type_interdit' => 'Заборонено завантаження цього типу файлів - @nom@',
	'erreur_upload_vignette' => 'При завантаженні мініатюри виникла помилка @nom@',
	'erreurs' => '@nb@ помилок',
	'erreurs_voir' => 'Продивитись помилки (@nb@) ',

	// F
	'fichier_distant' => 'Файл на іншому сайті',
	'fichier_manquant' => 'Файл не знайдено',
	'fichier_modifie' => 'Файл було змінено. Натисніть кнопку Зберегти.',
	'format_date_incorrect' => 'Невірна дата або час',

	// I
	'icone_creer_document' => 'Додати документ (файл)',
	'id' => 'ID',
	'image_tourner_180' => 'Поворот на 180°',
	'image_tourner_droite' => 'Поворот на 90° вправо',
	'image_tourner_gauche' => 'Поворот на 90° вліво',
	'info_dimensions_image' => 'Розміри',
	'info_doc_max_poids' => 'Розмір файлу має бути не більше @maxi@ (поточний розмір @actuel@).',
	'info_document' => 'Документ',
	'info_document_indisponible' => 'Цей документ недоступний',
	'info_documents' => 'Документи',
	'info_duree' => 'Тривалість ',
	'info_gauche_numero_document' => 'НОМЕР ДОКУМЕНТУ',
	'info_hauteur' => 'Висота',
	'info_heure' => 'Час',
	'info_illustrations' => 'Ілюстрації',
	'info_image_max_poids' => 'Розмір файлу зображення має бути менше @maxi@ (зараз @actuel@).',
	'info_image_max_taille' => 'Розмір файлу зображення має бути менше @maxi@ (зараз @actuel@).',
	'info_inclusion_directe' => 'Пряме включення:',
	'info_inclusion_vignette' => 'Додати мініатюру:',
	'info_installer_tous_documents' => 'Додати усі файли (документы)',
	'info_largeur' => 'Ширина',
	'info_logo_max_taille' => 'Логотипи мають бути менше, ніж @maxi@ (розмір цього файлу @actuel@).',
	'info_mode' => 'Режим (Mode)',
	'info_modifier_document' => 'Змінити файл',
	'info_portfolio' => 'Галерея фотографій і документів',
	'info_referencer_doc_distant' => 'Посилання на файл (URL):',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Без мініатюри',
	'info_statut_document' => 'Статус документу:',
	'info_taille' => 'Вага',
	'info_telecharger' => 'Завантажити з вашого комп’ютера:',
	'infos' => 'Технічна інформація',
	'item_autoriser_selectionner_date_en_ligne' => 'Дозволити змінювати дату додання документу',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Заборонити змінювати дату додання документу',

	// L
	'label_activer_document_objets' => 'Включити галерею:',
	'label_apercu' => 'Попередній перегляд',
	'label_caracteristiques' => 'Характеристики',
	'label_credits' => 'Інформація про автора',
	'label_fichier' => 'Файл',
	'label_fichier_vignette' => 'Мініатюра',
	'label_paginer_par' => 'Посторінково по:',
	'label_parents' => 'Документ використовується в:',
	'label_refdoc_joindre' => 'Номер документа',
	'lien_tout_desordonner_verif' => 'Порядок, встановлений для цього списку документів, буде скинуто. Ви впевнені?',
	'lien_tout_enlever' => 'Видалити усе',
	'logo' => 'Лого',

	// M
	'media_audio' => 'Аудіо',
	'media_file' => 'Інше',
	'media_image' => 'Зображення',
	'media_video' => 'Відео',
	'miniature_automatique_active' => 'SPIP створить мініатюру автоматично',

	// N
	'nb_documents_attache_succes' => 'Додано @nb@ документів (файлів)',
	'nb_documents_installe_succes' => 'Успішно додано @nb@ файлів',

	// O
	'objet_document' => 'Документ',
	'objet_documents' => 'Документи',
	'ordonner_ce_document' => 'Упорядкувати цей документ',

	// P
	'par_date' => 'Дата',
	'par_hauteur' => 'Висота',
	'par_id' => 'ID',
	'par_largeur' => 'Ширина',
	'par_taille' => 'Розмір',
	'par_titre' => 'Назва',

	// T
	'texte_documents_joints' => 'Ви можете включити можливість додавати файли і документи (аудіо, відео, офісні файли) до всіх матеріалів сайту.',
	'texte_documents_joints_2' => 'Вкажіть, до яких матеріалів можна додавати документи.',
	'titre_documents_joints' => 'Додання документів (файлів) до матеріалів',
	'titre_page_documents_edit' => 'Змінити документ: @titre@',
	'tous_les_medias' => 'Усі медіа файли',
	'tout_dossier_upload' => 'Увесь @upload@ каталог',
	'tout_voir' => 'Показати усі',

	// U
	'un_audio' => '1 аудіо файл',
	'un_document' => '1 документ (файл)',
	'un_file' => '1 документ (файл)',
	'un_image' => '1 зображення',
	'un_video' => '1 відео',
	'une_utilisation' => 'Використовується 1 раз',
	'upload_fichier_zip' => 'ZIP файл',
	'upload_fichier_zip_texte' => 'Файл, який ви маєте намір встановити, є архівом (zip).',
	'upload_fichier_zip_texte2' => 'Цей файл може бути:',
	'upload_info_mode_document' => 'Додати в галерею',
	'upload_info_mode_image' => 'Прибрати з галереї',
	'upload_limit' => 'Цей файл занадто великий для сервера; максимальний припустимий розмір @max@.',
	'upload_zip_conserver' => 'Не видаляти архів після витягання файлів',
	'upload_zip_decompacter' => 'розархівувати та встановити зміст кожного файлу на сайт. Будуть встановлені файли:',
	'upload_zip_mode_document' => 'Додати усі зображення в галерею',
	'upload_zip_telquel' => 'не розархівовувати, додати як ZIP-файл;',
	'upload_zip_titrer' => 'Створити назви відповідно до імен файлів',

	// V
	'verifier_documents_brises' => 'Перевірити відсутні файли',
	'verifier_documents_inutilises' => 'Перевірити використання документу',
	'vignette_supprimee' => 'Мініатюру видалено'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_grand' => 'Великий екран',
	'affichage_documents_en_liste_compacte' => 'Компактні списки',
	'aucun_audio' => 'Нема аудіо файлів ',
	'aucun_document' => 'Нема документів (файлів)',
	'aucun_file' => 'Нема документів (файлів)',
	'aucun_image' => 'Нема файлів зображень',
	'aucun_video' => 'Нема відео файлів',
	'aucune_utilisation' => 'Документ не використовується.',
	'aucune_vignette' => 'Нема мініатюр',

	// B
	'bouton_ajouter_document' => 'Додати документ',
	'bouton_ajouter_image' => 'Додати зображення',
	'bouton_ajouter_image_document' => 'Додати зображення або документ',
	'bouton_attacher_document' => 'Додати',
	'bouton_copier_local' => 'Додати на сайт',
	'bouton_download_depuis' => 'додати файли:',
	'bouton_download_local' => 'з мого комп’ютера',
	'bouton_download_par_ftp' => 'з сервера',
	'bouton_download_par_mediatheque' => 'із доданих',
	'bouton_download_sur_le_web' => 'з інтернету',
	'bouton_enlever_document' => 'Відкріпити',
	'bouton_enlever_supprimer_document' => 'Видалити',
	'bouton_enlever_supprimer_document_confirmation' => 'Ви певні, що хочете видалити документ (файл)?',
	'bouton_modifier_document' => 'Змінити',
	'bouton_parcourir' => 'Огляд...',
	'bouton_refresh_document' => 'Поновити документ',
	'bouton_remplacer_document' => 'Замінити документ',
	'bouton_remplacer_image' => 'Замінити зображення',
	'bouton_remplacer_image_document' => 'Замінити зображенням або файлом',
	'bouton_supprimer' => 'Видалити',
	'bouton_supprimer_tous_orphelins' => 'Видалити ті, що не використовуються', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Ви дійсно хочете видалити @nb@ документів (файлів)?', # MODIF
	'bouton_upload' => 'Додати',

	// D
	'des_audios' => '@nb@ аудіо файлів',
	'des_documents' => '@nb@ документів (файлів)',
	'des_files' => '@nb@ документів (файлів)',
	'des_images' => '@nb@ файлів зображень',
	'des_utilisations' => 'Використовується @nb@ раз(ів)',
	'des_videos' => '@nb@ відео файлів',
	'descriptif' => 'Опис',
	'details_document' => 'Деталі',
	'details_document_afficher_masquer' => 'Показати / сховати деталі документу',
	'document_attache_succes' => 'Документ (файл) доданий успішно',
	'document_copie_locale_succes' => 'Файл успішно скопійований на сайт',
	'document_installe_succes' => 'Файл доданий успішно',
	'document_vu' => 'В тексті',
	'documents' => 'Управління файлами',
	'documents_brises' => 'Пошкоджені',
	'documents_distants' => 'На інших сайтах',
	'documents_locaux' => 'На нашому сайті',
	'documents_non_publies' => 'Не опубліковані',
	'documents_orphelins' => 'Не використовуються',
	'documents_publies' => 'На сайті',
	'documents_tous' => 'Усі',
	'double_clic_inserer_doc' => 'Двічі клацніть, щоб вставити цей ярлик в текст',

	// E
	'entree_dimensions' => 'Розмір:',
	'entree_titre_document' => 'Назва документа:',
	'entree_titre_image' => 'Назва зображення:',
	'erreur_aucun_document' => 'Цього документу нема в модулі управління файлами',
	'erreur_aucun_fichier' => 'Файл не знайдений',
	'erreur_autorisation' => 'Проблема авторизації.',
	'erreur_chemin_distant' => 'Файл @nom@ з іншого сайту не знайдений',
	'erreur_chemin_ftp' => 'Не вдалося знайти вказаний файл на сервері',
	'erreur_copie_fichier' => 'Неможливо скопіювати файл @nom@ до вказаної папки',
	'erreur_deplacement_impossible' => 'Неможливо перемістити.',
	'erreur_dossier_tmp_manquant' => 'Не вдається створити тимчасову папку для завантаження файлів',
	'erreur_ecriture_fichier' => 'Помилка при спробі записати на диск',
	'erreur_format_fichier_image' => 'Формат файлу @nom@ не схожий на формат зображення',
	'erreur_indiquez_un_fichier' => 'Вкажіть файл!',
	'erreur_insertion_document_base' => 'Не вдається додати документ @fichier@ до бази даних',
	'erreur_objet_absent' => 'Інформації недостатньо.',
	'erreur_suppression_vignette' => 'При видаленні мініатюри виникла помилка',
	'erreur_upload_type_interdit' => 'Заборонено завантаження цього типу файлів - @nom@',
	'erreur_upload_vignette' => 'При завантаженні мініатюри виникла помилка @nom@',
	'erreurs' => '@nb@ помилок',
	'erreurs_voir' => 'Продивитись помилки (@nb@) ',

	// F
	'fichier_distant' => 'Файл на іншому сайті',
	'fichier_manquant' => 'Файл не знайдено',
	'fichier_modifie' => 'Файл було змінено. Натисніть кнопку Зберегти.',
	'format_date_incorrect' => 'Невірна дата або час',

	// I
	'icone_creer_document' => 'Додати документ (файл)',
	'id' => 'ID',
	'image_tourner_180' => 'Поворот на 180°',
	'image_tourner_droite' => 'Поворот на 90° вправо',
	'image_tourner_gauche' => 'Поворот на 90° вліво',
	'info_dimensions_image' => 'Розміри',
	'info_doc_max_poids' => 'Розмір файлу має бути не більше @maxi@ (поточний розмір @actuel@).',
	'info_document' => 'Документ',
	'info_document_indisponible' => 'Цей документ недоступний',
	'info_documents' => 'Документи',
	'info_duree' => 'Тривалість ',
	'info_gauche_numero_document' => 'НОМЕР ДОКУМЕНТУ',
	'info_hauteur' => 'Висота',
	'info_heure' => 'Час',
	'info_illustrations' => 'Ілюстрації',
	'info_image_max_poids' => 'Розмір файлу зображення має бути менше @maxi@ (зараз @actuel@).',
	'info_image_max_taille' => 'Розмір файлу зображення має бути менше @maxi@ (зараз @actuel@).',
	'info_inclusion_directe' => 'Пряме включення:',
	'info_inclusion_vignette' => 'Додати мініатюру:',
	'info_installer_tous_documents' => 'Додати усі файли (документы)',
	'info_largeur' => 'Ширина',
	'info_logo_max_taille' => 'Логотипи мають бути менше, ніж @maxi@ (розмір цього файлу @actuel@).',
	'info_mode' => 'Режим (Mode)',
	'info_modifier_document' => 'Змінити файл',
	'info_portfolio' => 'Галерея фотографій і документів',
	'info_referencer_doc_distant' => 'Посилання на файл (URL):',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Без мініатюри',
	'info_statut_document' => 'Статус документу:',
	'info_taille' => 'Вага',
	'info_telecharger' => 'Завантажити з вашого комп’ютера:',
	'infos' => 'Технічна інформація',
	'item_autoriser_selectionner_date_en_ligne' => 'Дозволити змінювати дату додання документу',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Заборонити змінювати дату додання документу',

	// L
	'label_activer_document_objets' => 'Включити галерею:',
	'label_apercu' => 'Попередній перегляд',
	'label_caracteristiques' => 'Характеристики',
	'label_credits' => 'Інформація про автора',
	'label_fichier' => 'Файл',
	'label_fichier_vignette' => 'Мініатюра',
	'label_paginer_par' => 'Посторінково по:',
	'label_parents' => 'Документ використовується в:',
	'label_refdoc_joindre' => 'Номер документа',
	'lien_tout_desordonner_verif' => 'Порядок, встановлений для цього списку документів, буде скинуто. Ви впевнені?',
	'lien_tout_enlever' => 'Видалити усе', # MODIF
	'logo' => 'Лого',

	// M
	'media_audio' => 'Аудіо',
	'media_file' => 'Інше',
	'media_image' => 'Зображення',
	'media_video' => 'Відео',
	'miniature_automatique_active' => 'SPIP створить мініатюру автоматично',

	// N
	'nb_documents_attache_succes' => 'Додано @nb@ документів (файлів)',
	'nb_documents_installe_succes' => 'Успішно додано @nb@ файлів',

	// O
	'objet_document' => 'Документ',
	'objet_documents' => 'Документи',
	'ordonner_ce_document' => 'Упорядкувати цей документ',

	// P
	'par_date' => 'Дата',
	'par_hauteur' => 'Висота',
	'par_id' => 'ID',
	'par_largeur' => 'Ширина',
	'par_taille' => 'Розмір',
	'par_titre' => 'Назва',

	// T
	'texte_documents_joints' => 'Ви можете включити можливість додавати файли і документи (аудіо, відео, офісні файли) до всіх матеріалів сайту.',
	'texte_documents_joints_2' => 'Вкажіть, до яких матеріалів можна додавати документи.',
	'titre_documents_joints' => 'Додання документів (файлів) до матеріалів',
	'titre_page_documents_edit' => 'Змінити документ: @titre@',
	'tous_les_medias' => 'Усі медіа файли',
	'tout_dossier_upload' => 'Увесь @upload@ каталог',
	'tout_voir' => 'Показати усі',

	// U
	'un_audio' => '1 аудіо файл',
	'un_document' => '1 документ (файл)',
	'un_file' => '1 документ (файл)',
	'un_image' => '1 зображення',
	'un_video' => '1 відео',
	'une_utilisation' => 'Використовується 1 раз',
	'upload_fichier_zip' => 'ZIP файл',
	'upload_fichier_zip_texte' => 'Файл, який ви маєте намір встановити, є архівом (zip).',
	'upload_fichier_zip_texte2' => 'Цей файл може бути:',
	'upload_info_mode_document' => 'Додати в галерею',
	'upload_info_mode_image' => 'Прибрати з галереї',
	'upload_limit' => 'Цей файл занадто великий для сервера; максимальний припустимий розмір @max@.',
	'upload_zip_conserver' => 'Не видаляти архів після витягання файлів',
	'upload_zip_decompacter' => 'розархівувати та встановити зміст кожного файлу на сайт. Будуть встановлені файли:',
	'upload_zip_mode_document' => 'Додати усі зображення в галерею',
	'upload_zip_telquel' => 'не розархівовувати, додати як ZIP-файл;',
	'upload_zip_titrer' => 'Створити назви відповідно до імен файлів',

	// V
	'verifier_documents_brises' => 'Перевірити відсутні файли',
	'verifier_documents_inutilises' => 'Перевірити використання документу',
	'vignette_supprimee' => 'Мініатюру видалено'
);
